@@ -153,10 +153,10 @@ gboolean oc_start_timer(Clock *clock)
         /* let's run it once in case we happened to kill it
            just when it was supposed to start */
             oc_get_time(clock); 
-        return(FALSE);
+        return(TRUE);
     }
     else
-        return(TRUE);
+        return(FALSE);
 }
 
 static void oc_end_tuning(Clock *clock)
@@ -167,9 +167,10 @@ static void oc_end_tuning(Clock *clock)
         g_source_remove(clock->adjust_timeout_id);
         clock->adjust_timeout_id = 0;
     }
-    if (clock->interval >= 60000) { /* resync it after each 6 hours */
+    if (clock->interval >= 60000) { /* resync it after each 4 hours */
+        oc_start_timer(clock);
         clock->adjust_timeout_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE
-                , 6*60*60*1000, (GSourceFunc)oc_start_timer, clock, NULL);
+                , 4*60*60*1000, (GSourceFunc)oc_start_timer, clock, NULL);
     }
     g_free(clock->tune);
     clock->tune = NULL;
@@ -472,9 +473,9 @@ static void oc_read_rc_file(XfcePanelPlugin *plugin, Clock *clock)
                 , (unsigned int *)&clock->bg.blue);
                 */
         sscanf(ret, "%uR %uG %uB", &red, &green, &blue);
-        clock->fg.red = red;
-        clock->fg.green = green;
-        clock->fg.blue = blue;
+        clock->bg.red = red;
+        clock->bg.green = green;
+        clock->bg.blue = blue;
         clock->bg.pixel = 0;
     }
 
